@@ -1,4 +1,5 @@
 import base64
+from functools import lru_cache
 import json
 import os
 import random
@@ -162,12 +163,25 @@ def docker(*command: str) -> int:
     return execute("docker", *command)
 
 
+@lru_cache(maxsize=None)
+def _docker_compose_command() -> Tuple[str, ...]:
+    """
+    A helper function to determine which program to call when running docker compose
+    """
+    if os.environ.get("TUTOR_USE_COMPOSE_SUBCOMMAND") is not None:
+        return ("docker", "compose")
+    if shutil.which("docker-compose") is not None:
+        return ("docker-compose",)
+    if shutil.which("docker") is not None:
+        if subprocess.run(["docker", "compose"], capture_output=True).returncode == 0:
+            return ("docker", "compose")
+    raise exceptions.TutorError(
+        "docker-compose is not installed. Please follow instructions from https://docs.docker.com/compose/install/"
+    )
+
+
 def docker_compose(*command: str) -> int:
-    if shutil.which("docker-compose") is None:
-        raise exceptions.TutorError(
-            "docker-compose is not installed. Please follow instructions from https://docs.docker.com/compose/install/"
-        )
-    return execute("docker-compose", *command)
+    return execute(*_docker_compose_command(), *command)
 
 
 def kubectl(*command: str) -> int:
